@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: keymap.c,v 1.16.2.1 2003/02/18 20:42:27 nalin Exp $"
+#ident "$Id: keymap.c,v 1.16.2.2 2003/02/21 04:02:58 nalin Exp $"
 #include "../config.h"
 #include <stdlib.h>
 #include <stdio.h>
@@ -153,37 +153,30 @@ static struct _vte_keymap_entry _vte_keymap_GDK_ISO_Left_Tab[] = {
 /* Various numeric keys enter control characters. */
 static struct _vte_keymap_entry _vte_keymap_GDK_2[] = {
 	{cursor_all, keypad_all, fkey_all, GDK_CONTROL_MASK, "\0", 1, NULL},
-	{cursor_all, keypad_all, fkey_all, 0, "2", 1, NULL},
 	{cursor_all, keypad_all, fkey_all, 0, NULL, 0, NULL},
 };
 static struct _vte_keymap_entry _vte_keymap_GDK_3[] = {
 	{cursor_all, keypad_all, fkey_all, GDK_CONTROL_MASK, "\033", 1, NULL},
-	{cursor_all, keypad_all, fkey_all, 0, "3", 1, NULL},
 	{cursor_all, keypad_all, fkey_all, 0, NULL, 0, NULL},
 };
 static struct _vte_keymap_entry _vte_keymap_GDK_4[] = {
 	{cursor_all, keypad_all, fkey_all, GDK_CONTROL_MASK, "\034", 1, NULL},
-	{cursor_all, keypad_all, fkey_all, 0, "4", 1, NULL},
 	{cursor_all, keypad_all, fkey_all, 0, NULL, 0, NULL},
 };
 static struct _vte_keymap_entry _vte_keymap_GDK_5[] = {
 	{cursor_all, keypad_all, fkey_all, GDK_CONTROL_MASK, "\035", 1, NULL},
-	{cursor_all, keypad_all, fkey_all, 0, "5", 1, NULL},
 	{cursor_all, keypad_all, fkey_all, 0, NULL, 0, NULL},
 };
 static struct _vte_keymap_entry _vte_keymap_GDK_6[] = {
 	{cursor_all, keypad_all, fkey_all, GDK_CONTROL_MASK, "\036", 1, NULL},
-	{cursor_all, keypad_all, fkey_all, 0, "6", 1, NULL},
 	{cursor_all, keypad_all, fkey_all, 0, NULL, 0, NULL},
 };
 static struct _vte_keymap_entry _vte_keymap_GDK_7[] = {
 	{cursor_all, keypad_all, fkey_all, GDK_CONTROL_MASK, "\037", 1, NULL},
-	{cursor_all, keypad_all, fkey_all, 0, "7", 1, NULL},
 	{cursor_all, keypad_all, fkey_all, 0, NULL, 0, NULL},
 };
 static struct _vte_keymap_entry _vte_keymap_GDK_8[] = {
 	{cursor_all, keypad_all, fkey_all, GDK_CONTROL_MASK, "\177", 1, NULL},
-	{cursor_all, keypad_all, fkey_all, 0, "8", 1, NULL},
 	{cursor_all, keypad_all, fkey_all, 0, NULL, 0, NULL},
 };
 
@@ -1002,8 +995,22 @@ _vte_keymap_map(guint keyval,
 			}
 			mods &= entries[j].mod_mask;
 		}
-		g_assert((fkey_mode == 0) || (fkey_mode == fkey_all));
-		g_assert(mods == 0);
+		switch (_vte_keymap[i].keyval) {
+		case GDK_2:
+		case GDK_3:
+		case GDK_4:
+		case GDK_5:
+		case GDK_6:
+		case GDK_7:
+		case GDK_8:
+			/* Known non-full-coverage cases. */
+			break;
+		default:
+			/* Everything else we double-check. */
+			g_assert((fkey_mode == 0) || (fkey_mode == fkey_all));
+			g_assert(mods == 0);
+			break;
+		}
 		entries = NULL;
 #endif
 		if (_vte_keymap[i].keyval == keyval) {
